#[non_exhaustive]pub enum SpawnError {
ReservedName(String),
DuplicateName(String),
StoreNotConfigured,
State(StateError),
}Expand description
Errors from task spawn operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReservedName(String)
The name is reserved by the system.
DuplicateName(String)
Another running task on this thread already has this name.
StoreNotConfigured
No state store has been configured for the manager.
State(StateError)
Commit to the state store failed.