pub struct Modalities {
pub input: Vec<Modality>,
pub output: Vec<Modality>,
}Expand description
Set of modalities a model accepts on input and produces on output.
Fields
input: Vec<Modality>output: Vec<Modality>Trait Implementations
Sourceimpl Clone for Modalities
impl Clone for Modalities
Sourcefn clone(&self) -> Modalities
fn clone(&self) -> Modalities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Modalities
impl Debug for Modalities
Sourceimpl Default for Modalities
impl Default for Modalities
Sourcefn default() -> Modalities
fn default() -> Modalities
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for Modalities
impl<'de> Deserialize<'de> for Modalities
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Modalities, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Modalities, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Modalities
Sourceimpl JsonSchema for Modalities
impl JsonSchema for Modalities
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Modalities
impl PartialEq for Modalities
Sourcefn eq(&self, other: &Modalities) -> bool
fn eq(&self, other: &Modalities) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Modalities
impl Serialize for Modalities
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Modalities